@@ -115,7 +115,7 @@ class TestBootParams(unittest.TestCase):
         try:
             tmp = tempfile.mkstemp()
             config = u("[blockdiag]\nfontpath = /path/to/font\n")
-            io.open(tmp[0], 'wt').write(config)
+            io.open(tmp[0], 'wt', encoding='utf-8-sig').write(config)
 
             options = self.parser.parse(['-c', tmp[1], 'input.diag'])
             self.assertEqual(options.font, ['/path/to/font'])
@@ -166,11 +166,6 @@ class TestBootParams(unittest.TestCase):
         with self.assertRaises(RuntimeError):
             self.parser.parse(['--size', 'foobar', 'input.diag'])
 
-    def test_auto_font_detection(self):
-        options = self.parser.parse(['input.diag'])
-        fontpath = detectfont(options)
-        self.assertTrue(fontpath)
-
     def test_not_exist_fontmap_config(self):
         with self.assertRaises(RuntimeError):
             args = ['--fontmap', '/fontmap_is_not_exist', 'input.diag']
