@@ -1,10 +1,16 @@
 # -*- coding: utf-8 -*-
 
-import unittest2
+import sys
+if sys.version_info < (2, 7):
+    import unittest2 as unittest
+else:
+    import unittest
+
 from blockdiag.imagedraw.textfolder import splitlabel
 from blockdiag.imagedraw.textfolder import splittext
 from blockdiag.imagedraw.textfolder import truncate_text
 from blockdiag.utils import Size
+from blockdiag.utils.compat import u
 
 
 CHAR_WIDTH = 14
@@ -17,43 +23,46 @@ class Metrics(object):
         return Size(CHAR_WIDTH * length, CHAR_HEIGHT)
 
 
-class TestTextFolder(unittest2.TestCase):
+class TestTextFolder(unittest.TestCase):
     def test_splitlabel(self):
         # single line text
         text = "abc"
-        self.assertItemsEqual(['abc'], splitlabel(text))
+        self.assertEqual(['abc'], list(splitlabel(text)))
 
         # text include \n (as char a.k.a. \x5c)
         text = "abc\ndef"
-        self.assertItemsEqual(['abc', 'def'], splitlabel(text))
+        self.assertEqual(['abc', 'def'], list(splitlabel(text)))
 
         # text include \n (as mac yensign a.k.a. \xa5)
         text = "abc\xa5ndef"
-        self.assertItemsEqual(['abc', 'def'], splitlabel(text))
+        self.assertEqual(['abc', 'def'], list(splitlabel(text)))
 
         # text includes \n (as text)
         text = "abc\\ndef"
-        self.assertItemsEqual(['abc', 'def'], splitlabel(text))
+        self.assertEqual(['abc', 'def'], list(splitlabel(text)))
 
         # text includes escaped \n
         text = "abc\\\\ndef"
-        self.assertItemsEqual(['abc\\ndef'], splitlabel(text))
+        self.assertEqual(['abc\\ndef'], list(splitlabel(text)))
 
         # text includes escaped \n (\x5c and mac yensign mixed)
-        text = u"abc\xa5\\ndef"
-        self.assertItemsEqual(['abc\\ndef'], splitlabel(text))
+        if sys.version_info[0] == 2:
+            text = u("abc\xa5\\\\ndef")
+        else:
+            text = u("abc\xa5\\ndef")
+        self.assertEqual(['abc\\ndef'], list(splitlabel(text)))
 
         # text include \n and spaces
         text = " abc \n def "
-        self.assertItemsEqual(['abc', 'def'], splitlabel(text))
+        self.assertEqual(['abc', 'def'], list(splitlabel(text)))
 
         # text starts empty line
         text = " \nabc\ndef"
-        self.assertItemsEqual(['abc', 'def'], splitlabel(text))
+        self.assertEqual(['abc', 'def'], list(splitlabel(text)))
 
         # text starts empty line with \n (as text)
         text = " \\nabc\\ndef"
-        self.assertItemsEqual(['', 'abc', 'def'], splitlabel(text))
+        self.assertEqual(['', 'abc', 'def'], list(splitlabel(text)))
 
     def test_splittext_width(self):
         metrics = Metrics()
